@@ -1,3 +1,4 @@
+#!/usr/bin/env bash
 
 # no early data, but TLS 1.3 with debian:buster (sid similar in Feb 2019)
 
@@ -23,9 +24,10 @@ docker exec -ti $ID service nginx start
 docker exec -ti $ID service nginx status
 # P Q
 
-docker inspect $ID | jq -r '.[].NetworkSettings.IPAddress'
+echo
+echo "You may now run \"testssl.sh $(docker inspect $ID --format '{{.NetworkSettings.IPAddress}}')\""
 
 exit 0
 
 
-
+#  vim:ts=5:sw=5:expandtab
